@@ -545,10 +545,19 @@ def getCMSversion(document_root = None):
 		default_site = hubzero.config.hubzerositeconfig.getHubDefaultSite()
 		document_root = hubzero.config.hubzerositeconfig.getHubzeroConfigOption(default_site, 'documentroot')
 
-	file_name = document_root + "/libraries/cms.php"
+	# 2.0.0 should actually look in core/libraries/Hubzero/Version/Version.php but the regex would be different
 
-	if os.path.isfile(file_name):
-		f = open(file_name, 'r')
+	if os.path.isfile(document_root + "/core//libraries/cms.php"):
+		f = open(document_root + "/core/libraries/cms.php", 'r')
+		file_text =  f.read()
+		p = re.compile(r"HVERSION['\"]+\s*,\s*['\"]+\s*(.*?)\s*['\"]+", re.MULTILINE)
+		m = p.search(file_text)
+		if not m:
+			return None
+		else:
+			return m.group(1)
+	if os.path.isfile(document_root + "/libraries/cms.php"):
+		f = open(document_root + "/libraries/cms.php", 'r')
 		file_text =  f.read()
 		p = re.compile(r"HVERSION['\"]+\s*,\s*['\"]+\s*(.*?)\s*['\"]+", re.MULTILINE)
 		m = p.search(file_text)
